==> monaco-vscode-debug-service-override-4.4.0.tgz: package/vscode/src/vs/workbench/contrib/debug/common/debugContentProvider.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { localizeWithPath } from 'vscode/vscode/vs/nls';
import { getMimeTypes } from 'vscode/vscode/vs/editor/common/services/languagesAssociations';
import { IModelService } from 'vscode/vscode/vs/editor/common/services/model';
import { ILanguageService } from 'vscode/vscode/vs/editor/common/languages/language';
import { ITextModelService } from 'vscode/vscode/vs/editor/common/services/resolverService';
import { IDebugService, DEBUG_SCHEME } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug';
import { Source } from 'vscode/vscode/vs/workbench/contrib/debug/common/debugSource';
import { IEditorWorkerService } from 'vscode/vscode/vs/editor/common/services/editorWorker';
import { EditOperation } from 'vscode/vscode/vs/editor/common/core/editOperation';
import { Range } from 'vscode/vscode/vs/editor/common/core/range';
import { CancellationTokenSource } from 'vscode/vscode/vs/base/common/cancellation';
import { PLAINTEXT_LANGUAGE_ID } from 'vscode/vscode/vs/editor/common/languages/modesRegistry';
import { ErrorNoTelemetry } from 'vscode/vscode/vs/base/common/errors';

var DebugContentProvider_1;
let DebugContentProvider = class DebugContentProvider {
    static { DebugContentProvider_1 = this; }
    constructor(textModelResolverService, debugService, modelService, languageService, editorWorkerService) {
        this.debugService = debugService;
        this.modelService = modelService;
        this.languageService = languageService;
        this.editorWorkerService = editorWorkerService;
        this.pendingUpdates = ( new Map());
        textModelResolverService.registerTextModelContentProvider(DEBUG_SCHEME, this);
        DebugContentProvider_1.INSTANCE = this;
    }
    dispose() {
        this.pendingUpdates.forEach(cancellationSource => cancellationSource.dispose());
    }
    provideTextContent(resource) {
        return this.createOrUpdateContentModel(resource, true);
    }
    static refreshDebugContent(resource) {
        DebugContentProvider_1.INSTANCE?.createOrUpdateContentModel(resource, false);
    }
    createOrUpdateContentModel(resource, createIfNotExists) {
        const model = this.modelService.getModel(resource);
        if (!model && !createIfNotExists) {
            return null;
        }
        let session;
        if (resource.query) {
            const data = Source.getEncodedDebugData(resource);
            session = this.debugService.getModel().getSession(data.sessionId);
        }
        if (!session) {
            session = this.debugService.getViewModel().focusedSession;
        }
        if (!session) {
            return Promise.reject(( new ErrorNoTelemetry(( localizeWithPath(
                'vs/workbench/contrib/debug/common/debugContentProvider',
                'unable',
                "Unable to resolve the resource without a debug session"
            )))));
        }
        const createErrModel = (errMsg) => {
            this.debugService.sourceIsNotAvailable(resource);
            const languageSelection = this.languageService.createById(PLAINTEXT_LANGUAGE_ID);
            const message = errMsg
                ? ( localizeWithPath(
                'vs/workbench/contrib/debug/common/debugContentProvider',
                'canNotResolveSourceWithError',
                "Could not load source '{0}': {1}.",
                resource.path,
                errMsg
            ))
                : ( localizeWithPath(
                'vs/workbench/contrib/debug/common/debugContentProvider',
                'canNotResolveSource',
                "Could not load source '{0}'.",
                resource.path
            ));
            return this.modelService.createModel(message, languageSelection, resource);
        };
        return session.loadSource(resource).then(response => {
            if (response && response.body) {
                if (model) {
                    const newContent = response.body.content;
                    const cancellationSource = this.pendingUpdates.get(model.id);
                    cancellationSource?.cancel();
                    const myToken = ( new CancellationTokenSource());
                    this.pendingUpdates.set(model.id, myToken);
                    return this.editorWorkerService.computeMoreMinimalEdits(model.uri, [{ text: newContent, range: model.getFullModelRange() }]).then(edits => {
                        this.pendingUpdates.delete(model.id);
                        if (!myToken.token.isCancellationRequested && edits && edits.length > 0) {
                            model.applyEdits(( edits.map(edit => EditOperation.replace(Range.lift(edit.range), edit.text))));
                        }
                        return model;
                    });
                }
                else {
                    const mime = response.body.mimeType || getMimeTypes(resource)[0];
                    const languageSelection = this.languageService.createByMimeType(mime);
                    return this.modelService.createModel(response.body.content, languageSelection, resource);
                }
            }
            return createErrModel();
        }, (err) => createErrModel(err.message));
    }
};
DebugContentProvider = DebugContentProvider_1 = ( __decorate([
    ( __param(0, ITextModelService)),
    ( __param(1, IDebugService)),
    ( __param(2, IModelService)),
    ( __param(3, ILanguageService)),
    ( __param(4, IEditorWorkerService))
], DebugContentProvider));

export { DebugContentProvider };

==> monaco-vscode-debug-service-override-4.5.0.tgz: package/vscode/src/vs/workbench/contrib/debug/common/debugContentProvider.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { localizeWithPath } from 'vscode/vscode/vs/nls';
import { getMimeTypes } from 'vscode/vscode/vs/editor/common/services/languagesAssociations';
import { IModelService } from 'vscode/vscode/vs/editor/common/services/model';
import { ILanguageService } from 'vscode/vscode/vs/editor/common/languages/language';
import { ITextModelService } from 'vscode/vscode/vs/editor/common/services/resolverService';
import { DEBUG_SCHEME } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug';
import { IDebugService } from 'vscode/vscode/vs/workbench/contrib/debug/common/debug.service';
import { Source } from 'vscode/vscode/vs/workbench/contrib/debug/common/debugSource';
import { IEditorWorkerService } from 'vscode/vscode/vs/editor/common/services/editorWorker';
import { EditOperation } from 'vscode/vscode/vs/editor/common/core/editOperation';
import { Range } from 'vscode/vscode/vs/editor/common/core/range';
import { CancellationTokenSource } from 'vscode/vscode/vs/base/common/cancellation';
import { PLAINTEXT_LANGUAGE_ID } from 'vscode/vscode/vs/editor/common/languages/modesRegistry';
import { ErrorNoTelemetry } from 'vscode/vscode/vs/base/common/errors';

var DebugContentProvider_1;
let DebugContentProvider = class DebugContentProvider {
    static { DebugContentProvider_1 = this; }
    constructor(textModelResolverService, debugService, modelService, languageService, editorWorkerService) {
        this.debugService = debugService;
        this.modelService = modelService;
        this.languageService = languageService;
        this.editorWorkerService = editorWorkerService;
        this.pendingUpdates = ( new Map());
        textModelResolverService.registerTextModelContentProvider(DEBUG_SCHEME, this);
        DebugContentProvider_1.INSTANCE = this;
    }
    dispose() {
        this.pendingUpdates.forEach(cancellationSource => cancellationSource.dispose());
    }
    provideTextContent(resource) {
        return this.createOrUpdateContentModel(resource, true);
    }
    static refreshDebugContent(resource) {
        DebugContentProvider_1.INSTANCE?.createOrUpdateContentModel(resource, false);
    }
    createOrUpdateContentModel(resource, createIfNotExists) {
        const model = this.modelService.getModel(resource);
        if (!model && !createIfNotExists) {
            return null;
        }
        let session;
        if (resource.query) {
            const data = Source.getEncodedDebugData(resource);
            session = this.debugService.getModel().getSession(data.sessionId);
        }
        if (!session) {
            session = this.debugService.getViewModel().focusedSession;
        }
        if (!session) {
            return Promise.reject(( new ErrorNoTelemetry(( localizeWithPath(
                'vs/workbench/contrib/debug/common/debugContentProvider',
                'unable',
                "Unable to resolve the resource without a debug session"
            )))));
        }
        const createErrModel = (errMsg) => {
            this.debugService.sourceIsNotAvailable(resource);
            const languageSelection = this.languageService.createById(PLAINTEXT_LANGUAGE_ID);
            const message = errMsg
                ? ( localizeWithPath(
                'vs/workbench/contrib/debug/common/debugContentProvider',
                'canNotResolveSourceWithError',
                "Could not load source '{0}': {1}.",
                resource.path,
                errMsg
            ))
                : ( localizeWithPath(
                'vs/workbench/contrib/debug/common/debugContentProvider',
                'canNotResolveSource',
                "Could not load source '{0}'.",
                resource.path
            ));
            return this.modelService.createModel(message, languageSelection, resource);
        };
        return session.loadSource(resource).then(response => {
            if (response && response.body) {
                if (model) {
                    const newContent = response.body.content;
                    const cancellationSource = this.pendingUpdates.get(model.id);
                    cancellationSource?.cancel();
                    const myToken = ( new CancellationTokenSource());
                    this.pendingUpdates.set(model.id, myToken);
                    return this.editorWorkerService.computeMoreMinimalEdits(model.uri, [{ text: newContent, range: model.getFullModelRange() }]).then(edits => {
                        this.pendingUpdates.delete(model.id);
                        if (!myToken.token.isCancellationRequested && edits && edits.length > 0) {
                            model.applyEdits(( edits.map(edit => EditOperation.replace(Range.lift(edit.range), edit.text))));
                        }
                        return model;
                    });
                }
                else {
                    const mime = response.body.mimeType || getMimeTypes(resource)[0];
                    const languageSelection = this.languageService.createByMimeType(mime);
                    return this.modelService.createModel(response.body.content, languageSelection, resource);
                }
            }
            return createErrModel();
        }, (err) => createErrModel(err.message));
    }
};
DebugContentProvider = DebugContentProvider_1 = ( __decorate([
    ( __param(0, ITextModelService)),
    ( __param(1, IDebugService)),
    ( __param(2, IModelService)),
    ( __param(3, ILanguageService)),
    ( __param(4, IEditorWorkerService))
], DebugContentProvider));

export { DebugContentProvider };
